#
# spec file for package scamper
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           scamper
Version:        20171204
Release:        lp150.1.2
Summary:        Parallel Internet measurement utility
License:        GPL-2.0
Group:          Productivity/Networking/Diagnostic
Url:            https://www.caida.org/tools/measurement/scamper/
Source:         https://www.caida.org/tools/measurement/%{name}/code/%{name}-cvs-%{version}.tar.gz
BuildRequires:  libopenssl-devel
BuildRequires:  pkgconfig

%description
Scamper is a program that is able to conduct Internet measurement
tasks to large numbers of IPv4 and IPv6 addresses, in parallel, to
fill a specified packets-per-second rate. Currently, it supports the
well-known ping and traceroute techniques, as well as MDA traceroute,
alias resolution, some parts of tbit, sting, and neighbour discovery.

Scamper can do ICMP-based Path MTU discovery. scamper starts with the
outgoing interface's MTU and discovers the location of Path MTU
bottlenecks. scamper performs a PMTUD search when an ICMP
fragmentation required message is not returned to establish the PMTU
to the next point in the network, followed by a TTL limited search to
infer where the failure appears to occur.

%package -n libscamperfile0
Summary:        File access library for scamper's binary dump format
Group:          System/Libraries

%description -n libscamperfile0
Scamper is a program that is able to conduct Internet measurement
tasks to large numbers of IPv4 and IPv6 addresses, in parallel, to
fill a specified packets-per-second rate. Currently, it supports the
well-known ping and traceroute techniques, as well as MDA traceroute,
alias resolution, some parts of tbit, sting, and neighbour discovery.

This package contains the library that provides access to the binary output
files that scamper can produce in certain modes.

%package -n libscamperfile-devel
Summary:        Development headers for scamper's binary dump file access library
Group:          Development/Libraries/Other
Requires:       libscamperfile0 = %{version}-%{release}

%description -n libscamperfile-devel
Scamper is a program that is able to conduct Internet measurement
tasks to large numbers of IPv4 and IPv6 addresses, in parallel, to
fill a specified packets-per-second rate. Currently, it supports the
well-known ping and traceroute techniques, as well as MDA traceroute,
alias resolution, some parts of tbit, sting, and neighbour discovery.

This package contains development headers and other ancillary files for the
libscamperfile library.

%prep
%setup -q -n %{name}-cvs-%{version}

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libscamperfile0 -p /sbin/ldconfig
%postun -n libscamperfile0 -p /sbin/ldconfig

%files
%doc COPYING
%{_bindir}/sc_*
%{_bindir}/scamper
%{_mandir}/man1/*
%{_mandir}/man5/*

%files -n libscamperfile0
%{_libdir}/libscamperfile.so.*

%files -n libscamperfile-devel
%{_includedir}/scamper_*
%{_libdir}/libscamperfile.so
%{_mandir}/man3/*

%changelog
* Mon Dec  4 2017 sebix+novell.com@sebix.at
- remove new-openssl.patch, included upstream
- update to version 20171204:
  - scamper:
  * add a blind-fin tbit test, which tests receiver behavior to TCP FIN
    packets which could have come from an off-path attacker.
  - sc_radargun:
  * add -d 2 option, which dumps interface IP-ID behavior classifications.
* Thu Nov 30 2017 sebix+novell.com@sebix.at
- add patch new-openssl.patch to compile with new openssl versions
* Thu Aug 24 2017 sebix+novell.com@sebix.at
- update to version 20170822
  scamper:
  * replace recursive versions of some functions with iterative versions.
  * add cycle-start and cycle-stop json record implementations.
  * fix traceroute json record: the hop transmit time value it reported
    was junk.
  * add support for sending json over the control socket.  use
    "attach format json" to get this mode; "attach" by itself still
    returns uuencoded warts.  Initial patch supplied by Young Hyun.
  * fix possible memory leaks detected with static analysis.
  * quality assurance on research paper cites in manual pages.
  * spelling errors noticed by Iain R. Learmonth.
  sc_ally:
  * add feature to dump inferred aliases from the collected data.
  sc_speedtrap:
  * add threaded implementation of pairwise comparison to form candidate
    alias sets, if pthreads are detected at compilation time and
  - -disable-threads configure option is not supplied.
  sc_uptime:
  * new scamper driver to infer IPv6 device reboot windows if the device
    returns an incrementing identifier field in the IPv6 fragmentation
    header.  the driver is not built by default, as it expects sqlite3.
    use --with-sc_uptime configure option to build.
    https://www.caida.org/~mjl/pubs/spf.pdf
* Thu Jun 22 2017 sebix+novell.com@sebix.at
- update to 20161204a
  * More fixes to libscamperfile caught with fuzz testing.  corrupt
  warts files provided by Greg Ward of Dyn
  * if targets or commands are specified in a file, and that file
  ends after all probing of commands in that file has completed,
  finish the source, allowing scamper to exit.  this scenario is
  most likely when stdin is the input file.  Reported by Alex
  Colvin of Dyn
  * use select/poll/epoll/kqueue to look for read events on stdin files
  * malloc enough memory for a prefix6_t in the prefixtree code.  reported
  by Sebastian Wagner via gcc7.  only sc_bdrmap uses that code
  * increase size of string buffers for some ping and trace fields for text
  output to silence gcc7 warning.
  * allow source IP address to be null when outputting a trace with json
  * update sc_tbitblind.1 man page to show correct use of scamper's IPFW
  firewall support, which changed in the 20161204 release
  * fix unlikely unaligned access when computing checksums with IPv6
  addresses
* Wed Jun 21 2017 sebix+novell.com@sebix.at
- update to 20161204
  * add remote control socket support to scamper.  scamper can be
  configured to connect to a remote controller at run time to
  allow remote systems to control a scamper instance.  the
  remote controller is handled by the sc_remoted utility, and
  is documented in the sc_remoted manual page (see below).
  * fixes to libscamperfile caught with fuzz testing.  corrupt
  warts data files provided by Greg Ward of Dyn.
  * add a PATRICIA trie implementation based off Sedgewick's
  Algorithms in C++ book.  this improves the performance
  of scamper compared to holding addresses in splaytrees.
  * improve speed of warts(5) code.
  * improve speed of scamper_writebuf by allocating pagesize blocks
  at a time.
  * begin to document ping warts records in warts(5).
  * fix debug printf implementation so that all features will
  be built in as long as --without-debugfile is not used.
  backported to 20141211g.
  * silence compiler warnings from Microsoft Visual Studio.
  backported to 20141211g.
  * sc_prefixscan:
  * add a utility, sc_prefixscan, that provides a convenient
    interface to scamper's prefixscan alias resolution method.
    https://www.caida.org/tools/measurement/scamper/man/sc_prefixscan.1.pdf
  * sc_radargun:
  * add a utility, sc_radargun, that provides a convenient
    interface to scamper's radargun implementation.
    https://www.caida.org/tools/measurement/scamper/man/sc_radargun.1.pdf
  * sc_remoted:
  * add a utility, sc_remoted, that provides an interface to a
    collection of remote scamper instances.
    https://www.caida.org/tools/measurement/scamper/man/sc_remoted.1.pdf
  * sc_ally:
  * use writebufs so sc_ally is event driven and will not block.
  * add code to probe candidate sets in pairs, with transitive
    closure to save probes.
  * allow inter-probe gaps of less than 1 second.
  * sc_attach:
  * add support for remote control sockets.
  * add an option to randomise the order tasks are run.
  * sc_speedtrap:
  * stricter default test for inferring if two IP addresses may
    share a single shared counter.
    backported to 20141211g.
  * code cleanup.
  * sc_warts2json
  * add support for printing ICMP extensions included in traceroute
    responses, prompted by Quirin Scheitle
* Sat Oct  8 2016 mardnh@gmx.de
- update to version 20141211e
  - upstream does not provide a changelog
* Sun Aug 21 2016 mardnh@gmx.de
- moved man3/* from lib- to -devel subpackage
- removed useless provides from libscamperfile0
* Wed Aug 17 2016 mardnh@gmx.de
- initial package, version 20141211e
